var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(
  // If the importer is in node compatibility mode or this is not an ESM
  // file that has been converted to a CommonJS file using a Babel-
  // compatible transform (i.e. "__esModule" has not been set), then set
  // "default" to the CommonJS "module.exports" for node compatibility.
  isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target,
  mod
));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/index.ts
var src_exports = {};
__export(src_exports, {
  StepResult: () => StepResultWithDefaults,
  createAgentTask: () => createAgentTask,
  default: () => src_default,
  executeAgentTaskStep: () => executeAgentTaskStep,
  getAgentTask: () => getAgentTask,
  getAgentTaskStep: () => getAgentTaskStep,
  listAgentTaskIDs: () => listAgentTaskIDs,
  listAgentTaskSteps: () => listAgentTaskSteps
});
module.exports = __toCommonJS(src_exports);

// src/agent.ts
var OpenApiValidator = __toESM(require("express-openapi-validator"));
var import_express = __toESM(require("express"));
var import_path = __toESM(require("path"));
var import_uuid = require("uuid");
var app = (0, import_express.default)();
app.use(import_express.default.json());
app.use(import_express.default.text());
app.use(import_express.default.urlencoded({ extended: false }));
var spec = import_path.default.join(__dirname, "../../openapi.yml");
app.use("/spec", import_express.default.static(spec));
app.use(
  OpenApiValidator.middleware({
    apiSpec: "../openapi.yml",
    validateRequests: true,
    // (default)
    validateResponses: true
    // false by default
  })
);
var tasks = [];
var steps = [];
var taskHandler = null;
var StepResultWithDefaults = class {
  constructor() {
    this.output = null;
    this.artifacts = [];
    this.is_last = false;
  }
};
var createAgentTask = async (body) => {
  if (taskHandler == null) {
    throw new Error("Task handler not defined");
  }
  const stepHandler = await taskHandler((body == null ? void 0 : body.input) ?? null);
  const task = {
    task_id: (0, import_uuid.v4)(),
    input: (body == null ? void 0 : body.input) ?? null,
    artifacts: []
  };
  tasks.push([task, stepHandler]);
  return task;
};
app.post("/agent/tasks", (req, res) => {
  void (async () => {
    try {
      const task = await createAgentTask(req.body);
      res.status(200).json(task);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var listAgentTaskIDs = async () => {
  return tasks.map(([task, _]) => task.task_id);
};
app.get("/agent/tasks", (req, res) => {
  void (async () => {
    try {
      const ids = await listAgentTaskIDs();
      res.status(200).json(ids);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var getAgentTask = async (taskId) => {
  const task = tasks.find(([task2, _]) => task2.task_id === taskId);
  if (task == null) {
    throw new Error(`Task with id ${taskId} not found`);
  }
  return task[0];
};
app.get("/agent/tasks/:task_id", (req, res) => {
  void (async () => {
    try {
      const task = await getAgentTask(req.params.task_id);
      res.status(200).json(task);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var listAgentTaskSteps = async (taskId) => {
  const task = tasks.find(([task2, _]) => task2.task_id === taskId);
  if (task == null) {
    throw new Error(`Task with id ${taskId} not found`);
  }
  return steps.filter((step) => step.task_id === taskId).map((step) => step.step_id);
};
app.get("/agent/tasks/:task_id/steps", (req, res) => {
  void (async () => {
    try {
      const ids = await listAgentTaskSteps(req.params.task_id);
      res.status(200).json(ids);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var executeAgentTaskStep = async (taskId, body) => {
  const task = tasks.find(([task2, _]) => task2.task_id === taskId);
  if (task == null) {
    throw new Error(`Task with id ${taskId} not found`);
  }
  const handler = task[1];
  const stepResult = await handler((body == null ? void 0 : body.input) ?? null);
  const step = {
    task_id: taskId,
    step_id: (0, import_uuid.v4)(),
    input: (body == null ? void 0 : body.input) ?? null,
    output: stepResult.output ?? null,
    artifacts: stepResult.artifacts ?? [],
    is_last: stepResult.is_last ?? false
  };
  if (step.artifacts != null) {
    if (task[0].artifacts == null || task[0].artifacts.length === 0) {
      task[0].artifacts = step.artifacts;
    } else {
      task[0].artifacts.push(...step.artifacts);
    }
  }
  steps.push(step);
  return step;
};
app.post("/agent/tasks/:task_id/steps", (req, res) => {
  void (async () => {
    try {
      const step = await executeAgentTaskStep(req.params.task_id, req.body);
      res.status(200).json(step);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var getAgentTaskStep = async (taskId, stepId) => {
  const step = steps.find(
    (step2) => step2.task_id === taskId && step2.step_id === stepId
  );
  if (step == null) {
    throw new Error(
      `Step with task id ${taskId} and step id ${stepId} not found`
    );
  }
  return step;
};
app.get("/agent/tasks/:task_id/steps/:step_id", (req, res) => {
  void (async () => {
    try {
      const step = await getAgentTaskStep(
        req.params.task_id,
        req.params.step_id
      );
      res.status(200).json(step);
    } catch (err) {
      console.error(err);
      res.status(500).json({ error: err.message });
    }
  })();
});
var Agent = class {
  static handleTask(handler) {
    taskHandler = handler;
    return this;
  }
  static start(port = 8e3) {
    app.listen(port, () => {
      console.log(`Agent listening at http://localhost:${port}`);
    });
  }
};

// src/index.ts
var src_default = Agent;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  StepResult,
  createAgentTask,
  executeAgentTaskStep,
  getAgentTask,
  getAgentTaskStep,
  listAgentTaskIDs,
  listAgentTaskSteps
});
